跳到主要内容

Coordinate

搜索

枚举 Coordinate 

源代码
pub enum Coordinate {
    Abs,
    Rel,
}
展开描述

指定坐标是相对坐标还是绝对坐标

变体



Abs



Rel

trait 实现

源代码

impl Clone for Coordinate

源代码

fn clone(&self) -> Coordinate

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 阅读更多
源代码

impl Debug for Coordinate

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Default for Coordinate

源代码

fn default() -> Coordinate

Returns the “default value” for a type. 阅读更多
源代码

impl Hash for Coordinate

源代码

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 阅读更多
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 阅读更多
源代码

impl PartialEq for Coordinate

源代码

fn eq(&self, other: &Coordinate) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.
源代码

impl Copy for Coordinate

源代码

impl Eq for Coordinate

源代码

impl StructuralPartialEq for Coordinate

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换是 From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

The resulting type after obtaining ownership.
源代码

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 阅读更多
源代码

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。