跳到主要内容

Settings

搜索

结构体 Settings 

源代码
pub struct Settings {
    pub linux_delay: u32,
    pub x11_display: Option<String>,
    pub wayland_display: Option<String>,
    pub windows_dw_extra_info: Option<usize>,
    pub event_source_user_data: Option<i64>,
    pub release_keys_when_dropped: bool,
    pub open_prompt_to_get_permissions: bool,
    pub independent_of_keyboard_state: bool,
    pub windows_subject_to_mouse_speed_and_acceleration_level: bool,
}
展开描述

用于创建 Enigo 结构体及其行为的设置

字段

linux_delay: u32

Linux X11 上的睡眠延迟

x11_display: Option<String>

使用 Linux X11 时要连接的显示名称

wayland_display: Option<String>

使用 Linux Wayland 时要连接的显示名称

windows_dw_extra_info: Option<usize>

用于区分由 enigo 创建的事件的任意值 所有事件都会在 dwExtraInfo 字段中标记此值

event_source_user_data: Option<i64>

用于区分由 enigo 创建的事件的任意值 所有事件都会在 EVENT_SOURCE_USER_DATA 字段中标记此值

release_keys_when_dropped: bool

如果希望在 Enigo 被 drop 时释放所有按住的按键,请将此值设置为 true。默认值为 true。

open_prompt_to_get_permissions: bool

在缺少模拟输入权限时打开一个提示,向用户请求该权限。仅在 macOS 上可用。默认值为 true。

independent_of_keyboard_state: bool

模拟输入与物理键盘上按下的按键无关。仅在 macOS 上可用。 默认值为 true。例如当 Shift 键被按下时,后续模拟的输入不会被大写化。

windows_subject_to_mouse_speed_and_acceleration_level: bool

如果设置为 true,相对鼠标移动将受到鼠标速度和加速度级别设置的影响。最终用户可以在控制面板的"鼠标"应用中设置这些值。应用程序可以通过 windows::Win32::UI::WindowsAndMessaging::SystemParametersInfoA 函数获取和设置这些值。默认值为 false。

trait 实现

源代码

impl Clone for Settings

源代码

fn clone(&self) -> Settings

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

Performs copy-assignment from source. 阅读更多
源代码

impl Debug for Settings

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Default for Settings

源代码

fn default() -> Self

Returns the “default value” for a type. 阅读更多
源代码

impl Hash for Settings

源代码

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 阅读更多
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 阅读更多
源代码

impl PartialEq for Settings

源代码

fn eq(&self, other: &Settings) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

Tests for !=. The default implementation is almost always sufficient, and should not be overridden without very good reason.
源代码

impl Eq for Settings

源代码

impl StructuralPartialEq for Settings

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from self to dest. 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

调用 U::from(self)

也就是说,此转换是 From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

The resulting type after obtaining ownership.
源代码

fn to_owned(&self) -> T

Creates owned data from borrowed data, usually by cloning. 阅读更多
源代码

fn clone_into(&self, target: &mut T)

Uses borrowed data to replace owned data, usually by cloning. 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。